@@ -1,6 +1,9 @@
-/* organise.c (acdc) - copyright Mike Arnautov 1990-2020.
+/* organise.c (acdc) - copyright Mike Arnautov 1990-2023.
  * Licensed under GPL, version 3 or later (see the supplied LICENCE file).
  *
+ *                           
+ * 10 Mar 22   MLA           Define DUMP if necessary.
+ * 24 Feb 22   MLA           Mandate ENTNAME in debug mode.
  * 13 Aug 21   MLA           Added definition of NOWORD.
  * 03 Aug 21   MLA           Finalised internationalisation changes.
  * 31 Jul 21   MLA           Allowed barred names for internationalisation.
@@ -9,8 +12,7 @@
  * 22 Jun 20   MLA           Move writing off VOCAB_SIZE to finalise.c
  * 21 Jun 20   MLA           Use mandate() to auto-define various things.
  * 02 Nov 18   MLA           Conditionally added SEEN.
- * 03 Oct 18   MLA           Addded NO_MATCH and NO_AMATCH.
- *                           declarations. 
+ * 03 Oct 18   MLA           Addded NO_MATCH and NO_AMATCH declarations. 
  * 18 Aug 18   MLA           Ditched some redundant UNDO flags.
  * 22 Apr 16   MLA           bug: in str(n)cpy string args should not overlap.
  * 03 Mar 16   MLA           Removed non-ANSI C support.
@@ -70,7 +72,7 @@
  */
  
 #include <stdio.h>
-// #include <ctype.h>
+/* #include <ctype.h> */
 #include <string.h>
 #include <stdarg.h>
 
@@ -184,8 +186,12 @@ void mandate (char *item, int type, ...)
       ap = addsymb (AUTOSYMBOL, item, type, type_counts[type]++);
       if (type == OBJ || type == WORD)
       {
-        if (!(np = fndsymb(VOCAB, item))) // Might be declared as NOISE!
+        if (!(np = fndsymb(VOCAB, item))) /* Might be declared as NOISE! */
            np = storword (item, type, next_vocaddr);
+/* The ++ in the following line is an error, effectively wasting a refno.
+ * However, fixing it would break upward compatibility of saved games!
+ * Should fix it in version 13!!
+ */ 
         np -> refno = type_counts[type]++;
         np -> symbol = ap;
       }
@@ -280,8 +286,10 @@ void organise(void)
    fprintf (code_file, "#include \"adv3.h\"\n");
 
    next_addr = 0;
-   if (debug)     /* Declarations over - if source output */
-      debug = 2;  /* is required, turn it on! */
+/*
+//   if (debug)     // Declarations over - if source output
+//      debug = 2;  // is required, turn it on!
+*/
 
    if (*title)
       strcpy (dbname, title);
@@ -429,6 +437,8 @@ void organise(void)
    mandate ("arg1", VAR);
    mandate ("arg2", VAR);
    mandate ("arg3", VAR);
+   if (debug)
+     mandate("entname", VAR);
 
 /* 
  * Variable ENTNAME is very special! It causes symbolic names of all
@@ -524,6 +534,9 @@ void organise(void)
       (defs_file, "#define LVERB %d\n", type_base[VERB + 1] - 1);
    fprintf
       (defs_file, "#define FVAR %d\n", type_base[VAR]);
+/* The definition of LVAR is one too high, but fixing this breaks
+ * saved game compatibility. Should fix in version 13!
+ */
    fprintf
       (defs_file, "#define LVAR %d\n", type_base[VAR + 1]);
    fprintf (defs_file, "#define FTEXT %d\n", type_base[TEXT]);
@@ -731,6 +744,14 @@ void organise(void)
          fprintf (defs_file, "#define SAY %d\n", np -> refno);
    }
    
+   if ((np = fndsymb(TESTSYMBOL, "dumpdata")) != NULL)
+   {
+      if (np -> type != VERB)
+         gripe ("dumpdata", "Declared as other than a verb.");
+      else
+         fprintf (defs_file, "#define DUMP %d\n", np -> refno);
+   }
+   
    next_constant = -1;
    declare_constant ("noword",  "NOWORD",  next_constant--);
    declare_constant ("badword", "BADWORD", next_constant--);
@@ -744,8 +765,8 @@ void organise(void)
    }
    if (style >= 10)
    {
-      declare_constant ("no.match",  "NO_MATCH",  98);
-      declare_constant ("no.amatch", "NO_AMATCH", 99);
+      declare_constant ("no.match",  "NO_MATCH",   98);
+      declare_constant ("no.amatch", "NO_AMATCH",  99);
    }
    if (style < 10)
    {
@@ -769,14 +790,17 @@ void organise(void)
       fprintf (defs_file, "#define VERB %d\n", VERBFLAG);
    }
 
+   define_constant ("full.display",  "FULL",     "flag or synonym");
    define_constant ("fulldisplay",   "FULL",     "flag or synonym");
    define_constant ("fulldisp",      "FULL",     "flag or synonym");
-   define_constant ("beenhere",      "BEENHERE", "flag or synonym");
-   define_constant ("been.here",     "BEENHERE", "flag or synonym");
-   define_constant ("fastmode",      "TERSE",    "flag or synonym");
+   define_constant ("terse.display", "TERSE",    "flag or synonym");
    define_constant ("tersedisplay",  "TERSE",    "flag or synonym");
-   define_constant ("quickie",       "BRIEF",    "flag or synonym");
+   define_constant ("fastmode",      "TERSE",    "flag or synonym");
+   define_constant ("brief.display", "BRIEF",    "flag or synonym");
    define_constant ("briefdisplay",  "BRIEF",    "flag or synonym");
+   define_constant ("quickie",       "BRIEF",    "flag or synonym");
+   define_constant ("been.here",     "BEENHERE", "flag or synonym");
+   define_constant ("beenhere",      "BEENHERE", "flag or synonym");
 
    fprintf (defs_file, "#define PLAIN %d\n", plain_text ? 1 : 0);
 
@@ -811,7 +835,7 @@ void organise(void)
    fprintf (defs_file, "#define CENTRE_START 0%o\n", CENTRE_START);
    if (style > 10)
      fprintf (defs_file, "#define VHOLDER      0%o\n", VHOLDER);
-     fprintf (defs_file, "#define UTF8         %d\n",  1);
+     fprintf (defs_file, "#define UTF8         %d\n",  utf8);
    stage = 1;        /* Restore stage value */
    return;
 }
